==> servicecatalog-model-5.10.2-sources.jar: io/fabric8/servicecatalog/api/model/ClusterServiceBrokerSpecBuilder.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClusterServiceBrokerSpecBuilder extends io.fabric8.servicecatalog.api.model.ClusterServiceBrokerSpecFluentImpl<io.fabric8.servicecatalog.api.model.ClusterServiceBrokerSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.servicecatalog.api.model.ClusterServiceBrokerSpec,io.fabric8.servicecatalog.api.model.ClusterServiceBrokerSpecBuilder>{
  public ClusterServiceBrokerSpecBuilder() {
    this(false);
  }
  public ClusterServiceBrokerSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new ClusterServiceBrokerSpec(), validationEnabled);
  }
  public ClusterServiceBrokerSpecBuilder(io.fabric8.servicecatalog.api.model.ClusterServiceBrokerSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterServiceBrokerSpecBuilder(io.fabric8.servicecatalog.api.model.ClusterServiceBrokerSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClusterServiceBrokerSpec(), validationEnabled);
  }
  public ClusterServiceBrokerSpecBuilder(io.fabric8.servicecatalog.api.model.ClusterServiceBrokerSpecFluent<?> fluent,io.fabric8.servicecatalog.api.model.ClusterServiceBrokerSpec instance) {
    this(fluent, instance, false);
  }
  public ClusterServiceBrokerSpecBuilder(io.fabric8.servicecatalog.api.model.ClusterServiceBrokerSpecFluent<?> fluent,io.fabric8.servicecatalog.api.model.ClusterServiceBrokerSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAuthInfo(instance.getAuthInfo()); 
    fluent.withCaBundle(instance.getCaBundle()); 
    fluent.withCatalogRestrictions(instance.getCatalogRestrictions()); 
    fluent.withInsecureSkipTLSVerify(instance.getInsecureSkipTLSVerify()); 
    fluent.withRelistBehavior(instance.getRelistBehavior()); 
    fluent.withRelistDuration(instance.getRelistDuration()); 
    fluent.withRelistRequests(instance.getRelistRequests()); 
    fluent.withUrl(instance.getUrl()); 
    this.validationEnabled = validationEnabled; 
  }
  public ClusterServiceBrokerSpecBuilder(io.fabric8.servicecatalog.api.model.ClusterServiceBrokerSpec instance) {
    this(instance,false);
  }
  public ClusterServiceBrokerSpecBuilder(io.fabric8.servicecatalog.api.model.ClusterServiceBrokerSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAuthInfo(instance.getAuthInfo()); 
    this.withCaBundle(instance.getCaBundle()); 
    this.withCatalogRestrictions(instance.getCatalogRestrictions()); 
    this.withInsecureSkipTLSVerify(instance.getInsecureSkipTLSVerify()); 
    this.withRelistBehavior(instance.getRelistBehavior()); 
    this.withRelistDuration(instance.getRelistDuration()); 
    this.withRelistRequests(instance.getRelistRequests()); 
    this.withUrl(instance.getUrl()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.servicecatalog.api.model.ClusterServiceBrokerSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.servicecatalog.api.model.ClusterServiceBrokerSpec build() {
    ClusterServiceBrokerSpec buildable = new ClusterServiceBrokerSpec(fluent.getAuthInfo(),fluent.getCaBundle(),fluent.getCatalogRestrictions(),fluent.getInsecureSkipTLSVerify(),fluent.getRelistBehavior(),fluent.getRelistDuration(),fluent.getRelistRequests(),fluent.getUrl());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterServiceBrokerSpecBuilder that = (ClusterServiceBrokerSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> servicecatalog-model-6.2.0-sources.jar: io/fabric8/servicecatalog/api/model/ClusterServiceBrokerSpecBuilder.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterServiceBrokerSpecBuilder extends ClusterServiceBrokerSpecFluentImpl<ClusterServiceBrokerSpecBuilder> implements VisitableBuilder<ClusterServiceBrokerSpec,ClusterServiceBrokerSpecBuilder>{
  public ClusterServiceBrokerSpecBuilder() {
    this(false);
  }
  public ClusterServiceBrokerSpecBuilder(Boolean validationEnabled) {
    this(new ClusterServiceBrokerSpec(), validationEnabled);
  }
  public ClusterServiceBrokerSpecBuilder(ClusterServiceBrokerSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterServiceBrokerSpecBuilder(ClusterServiceBrokerSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterServiceBrokerSpec(), validationEnabled);
  }
  public ClusterServiceBrokerSpecBuilder(ClusterServiceBrokerSpecFluent<?> fluent,ClusterServiceBrokerSpec instance) {
    this(fluent, instance, false);
  }
  public ClusterServiceBrokerSpecBuilder(ClusterServiceBrokerSpecFluent<?> fluent,ClusterServiceBrokerSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAuthInfo(instance.getAuthInfo()); 
    fluent.withCaBundle(instance.getCaBundle()); 
    fluent.withCatalogRestrictions(instance.getCatalogRestrictions()); 
    fluent.withInsecureSkipTLSVerify(instance.getInsecureSkipTLSVerify()); 
    fluent.withRelistBehavior(instance.getRelistBehavior()); 
    fluent.withRelistDuration(instance.getRelistDuration()); 
    fluent.withRelistRequests(instance.getRelistRequests()); 
    fluent.withUrl(instance.getUrl()); 
    this.validationEnabled = validationEnabled; 
  }
  public ClusterServiceBrokerSpecBuilder(ClusterServiceBrokerSpec instance) {
    this(instance,false);
  }
  public ClusterServiceBrokerSpecBuilder(ClusterServiceBrokerSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAuthInfo(instance.getAuthInfo()); 
    this.withCaBundle(instance.getCaBundle()); 
    this.withCatalogRestrictions(instance.getCatalogRestrictions()); 
    this.withInsecureSkipTLSVerify(instance.getInsecureSkipTLSVerify()); 
    this.withRelistBehavior(instance.getRelistBehavior()); 
    this.withRelistDuration(instance.getRelistDuration()); 
    this.withRelistRequests(instance.getRelistRequests()); 
    this.withUrl(instance.getUrl()); 
    this.validationEnabled = validationEnabled; 
  }
  ClusterServiceBrokerSpecFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterServiceBrokerSpec build() {
    ClusterServiceBrokerSpec buildable = new ClusterServiceBrokerSpec(fluent.getAuthInfo(),fluent.getCaBundle(),fluent.getCatalogRestrictions(),fluent.getInsecureSkipTLSVerify(),fluent.getRelistBehavior(),fluent.getRelistDuration(),fluent.getRelistRequests(),fluent.getUrl());
    return buildable;
  }
  
}
